@@ -34,7 +34,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
-#include <getopt.h>
 #include "app.h"
 #include "about.h"
 #include "help.h"
@@ -147,9 +146,9 @@ app(void)
   gtk_window_set_wmclass(GTK_WINDOW(wi), "geg", "Geg");
   gtk_window_set_title(GTK_WINDOW(wi), "geg");
   gtk_window_set_policy(GTK_WINDOW(wi), TRUE, TRUE, TRUE);
-  gtk_signal_connect(GTK_OBJECT(wi), "delete_event", 
+  gtk_signal_connect(GTK_OBJECT(wi), "delete_event",
                      GTK_SIGNAL_FUNC(delete_event), NULL);
-  gtk_signal_connect(GTK_OBJECT(wi), "destroy", 
+  gtk_signal_connect(GTK_OBJECT(wi), "destroy",
                      GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 
   main_vb = gtk_vbox_new(FALSE, 0);
@@ -166,7 +165,7 @@ app(void)
   work_hb = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(main_vb), work_hb, TRUE, TRUE, 0);
   gtk_widget_show(work_hb);
-  
+
   hs = gtk_hseparator_new();
   gtk_box_pack_start(GTK_BOX(main_vb), hs, FALSE, TRUE, 0);
   gtk_widget_show(hs);
@@ -548,7 +547,7 @@ update_ranges(void)
   gtk_entry_set_text(GTK_ENTRY(xmax_en), buf_2->str);
   /* gtk_signal_emit_stop_by_name(GTK_OBJECT(xmax_en), "changed"); */
 
-  g_string_sprintf(buf_1, "%%0.%df", 
+  g_string_sprintf(buf_1, "%%0.%df",
 		   CLAMP((gint)ceil(-log10(height / 100)), 0, 6));
 
   g_string_sprintf(buf_2, buf_1->str, ymin);
@@ -573,7 +572,7 @@ zoom_event(GtkWidget *widget, gpointer data)
 {
   gdouble x = 0, y = 0;
   gdouble width, height;
-  
+
   if(!range_ok(FALSE))
    return;
 
@@ -586,8 +585,11 @@ zoom_event(GtkWidget *widget, gpointer data)
       write_log(NULL, "Minimum Resolution");
       return;
     }
-    x = width * (prefs.zoom / 4);
-    y = height * (prefs.zoom / 4);
+
+    x = - prefs.zoom / 2 * (width / (1 + prefs.zoom));
+    y = - prefs.zoom / 2 * (height / (1 + prefs.zoom));
+
+
     write_log(NULL, "Zoom In");
   }
   else if(!strcmp((char *)data, "out")) {
@@ -596,17 +598,19 @@ zoom_event(GtkWidget *widget, gpointer data)
       write_log(NULL, "Maximum Resolution");
       return;
     }
-    x = -width * (1 + 2 * prefs.zoom) * (prefs.zoom / 4);
-    y = -height * (1 + 2 * prefs.zoom) * (prefs.zoom / 4);
+
+    x = prefs.zoom / 2 * width;
+    y = prefs.zoom / 2 * height;
+
     write_log(NULL, "Zoom Out");
   }
   else
     g_assert_not_reached();
 
-  xmin += x;
-  xmax -= x;
-  ymin += y;
-  ymax -= y;
+  xmin -= x;
+  xmax += x;
+  ymin -= y;
+  ymax += y;
 
   update_ranges();
   clear_pixmap();
@@ -626,14 +630,14 @@ go_event(GtkWidget *widget, gpointer data)
   GList *temp_list;
 #endif
   static GList *list = NULL;
-  
+
   combo = (GtkWidget *)data;
   formula = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry));
 
   /* draw the formula and add it to the list if it parses ok */
   if(!formula_add((FormulaFunc)draw_formula, formula))
     return;
-  
+
   /* remove the formula from the list if it is already in there somewhere */
 #if(!((GTK_MAJOR_VERSION == 1) && (GTK_MINOR_VERSION == 0)))
   temp_list = g_list_find_custom(list, formula, (GCompareFunc)g_strcasecmp);
@@ -644,11 +648,11 @@ go_event(GtkWidget *widget, gpointer data)
   /* add the formula to the top of the list */
   list = g_list_prepend(list, strdup(formula));
   gtk_combo_set_popdown_strings(GTK_COMBO(combo), list);
-  
+
   /* keep the list a reasonable length */
   while(g_list_length(list) > 8)
     g_list_remove_link(list, g_list_last(list));
-  
+
   redraw_event(da, NULL);
 }
 
@@ -1100,6 +1104,10 @@ release_event(GtkWidget *widget, GdkEventButton *event, gpointer data)
   /* if the user pressed and released the button nearby, we'll let 'em off */
   if((abs(x_up - x_down) < MINSEL) && (abs(y_up - y_down) < MINSEL))
     return;
+
+  /* check for zero width or zero height */
+  if((x_up == x_down) || (y_up == y_down))
+    return;
   
   x1 = (x_down < x_up) ? real_x(x_down) : real_x(x_up);
   x2 = (x_down > x_up) ? real_x(x_down) : real_x(x_up);
@@ -1252,8 +1260,6 @@ configure_event(GtkWidget *widget, GdkEventConfigure *event, gpointer data)
   pixmap_width = widget->allocation.width;
   pixmap_height = widget->allocation.height;
 
-  gtk_drawing_area_size(GTK_DRAWING_AREA(widget), pixmap_width, pixmap_height);
-
   /* create a new pixmap of a size equal to the drawing area */
   pixmap = gdk_pixmap_new(widget->window, pixmap_width, pixmap_height, -1);
   /* clear the pixmap to the user's background color */
@@ -1307,12 +1313,12 @@ drawing_init(GtkWidget *widget, gpointer data)
 				       zoom_width, zoom_height, 1,
 				       &black, &white);
   mask = gdk_pixmap_create_from_data(widget->window, zoom_m_bits,
-				       zoom_m_width, zoom_m_height, 1,
-				       &black, &white);
+				     zoom_m_width, zoom_m_height, 1,
+				     &black, &white);
   cursors[1] = gdk_cursor_new_from_pixmap(source, mask, 
 					  &black, 
 					  &white, 
-					  zoom_x_hot, zoom_y_hot);
+					  0, 0);
 
   source = gdk_pixmap_create_from_data(widget->window, fint_bits,
 				       fint_width, fint_height, 1,
@@ -1323,7 +1329,7 @@ drawing_init(GtkWidget *widget, gpointer data)
   cursors[2] = gdk_cursor_new_from_pixmap(source, mask, 
 					  &black, 
 					  &white, 
-					  fint_x_hot, fint_y_hot);
+					  0, 0);
 
   source = gdk_pixmap_create_from_data(widget->window, aint_bits,
 				       aint_width, aint_height, 1,
@@ -1334,7 +1340,7 @@ drawing_init(GtkWidget *widget, gpointer data)
   cursors[3] = gdk_cursor_new_from_pixmap(source, mask, 
 					  &black, 
 					  &white, 
-					  aint_x_hot, aint_y_hot);
+					  0, 0);
   
   /* set the drawing area window's cursor to the default cursor */
   gdk_window_set_cursor(widget->window, cursors[0]);
