@@ -55,10 +55,9 @@ static gchar *help_text =
 "    x         (Variable Parameter)\n" \
 "\n" \
 "The Extended Backus Naur Notation (EBNF used in geg is:\n" \
-"    <expression> ::= <term>   { + | - <term> }\n" \
+"    <expression> ::= [ + | - ] <term>   { + | - <term> }\n" \
 "    <term>       ::= <factor> { * | / | ^ <factor> }\n" \
-"    <factor>     ::= <number> | <function> |\n" \
-"                     (<expression>) | -<factor>\n" \
+"    <factor>     ::= <number> | <function> | (<expression>)\n" \
 "    <number>     ::= <float> | x\n" \
 "    <function>   ::= <function_name>(<expression>)\n";
 
@@ -120,7 +119,7 @@ help_event(GtkWidget *widget, gpointer data)
   gtk_widget_show(hb);
 
   te = gtk_text_new(NULL, NULL);
-  gtk_widget_set_usize(te, 60 * gdk_char_width(font, ' '), 400);
+  gtk_widget_set_usize(te, 65 * gdk_char_width(font, ' '), 400);
   gtk_text_set_word_wrap(GTK_TEXT(te), FALSE);
   gtk_box_pack_start(GTK_BOX(hb), te, TRUE, TRUE, 0);
   gtk_widget_show(te);
