@@ -5,7 +5,12 @@
 
 /*
  * Corrected grammar
- * Kris Jurka 7/27/1999
+ * Kris Jurka 27/7/1999
+ */
+
+/*
+ * Corrected more grammar
+ * Torsten Landschoff 24/11/1999
  */
 
 #ifdef HAVE_CONFIG_H
@@ -20,10 +25,10 @@
 /*
  *
  * EBNF:
- *  <expr>     ::= <term> { +|- <term> }
+ *  <expr>     ::= +|- <term> { +|- <term> }
  *  <term>     ::= <product> { *|/ <product> }
  *  <product>  ::= <factor> { ^ <factor> }
- *  <factor>   ::= <number> | <function> | (<expr>) | -<factor>
+ *  <factor>   ::= <number> | <function> | (<expr>)
  *  <number>   ::= <float> | x
  *  <function> ::= <function_name>(<expression>)
  */
@@ -137,7 +142,20 @@ term(void)
      token_type_is(LB)	||
      token_type_is(LCB) ||
      token_type_is(LSB)) {
-    tree = product();
+    if(token_type_is(SUB)) {	/* negate */
+      tree = g_new(parse_tree, 1);
+      tree->token.type = SUB;	/* token_type(); */
+      tree->left = g_new(parse_tree, 1);
+      tree->left->token.type = NUM;
+      tree->left->token.value = 0;
+      tree->left->left = NULL;
+      tree->left->right = NULL;
+      get_next_token();		/* skip the minus-sign */
+      tree->right = product();
+    }
+    else {
+      tree = product();
+    }
   }
   else {
     parse_error = TRUE;
@@ -187,7 +205,6 @@ product(void)
   if(token_type_is(NUM) ||
      token_type_is(X)   ||
      token_type_is(FUN) ||
-     token_type_is(SUB) ||	/* negate, (not minus) */
      token_type_is(LB)	||
      token_type_is(LCB) ||
      token_type_is(LSB)) {
@@ -273,18 +290,6 @@ factor(void)
     skip_token(RCB);
     return(tree);
   }
-  else if(token_type_is(SUB)) {	/* negate */
-    tree = g_new(parse_tree, 1);
-    tree->token.type = SUB;	/* token_type(); */
-    tree->left = g_new(parse_tree, 1);
-    tree->left->token.type = NUM;
-    tree->left->token.value = 0;
-    tree->left->left = NULL;
-    tree->left->right = NULL;
-    get_next_token();		/* skip the minus-sign */
-    tree->right = factor();
-    return(tree);
-  }
   else {
     parse_error = TRUE;
     return(NULL);
