@@ -454,16 +454,16 @@ widgets_to_prefs(GtkWidget *widget, gpointer data)
 
   /* startup options */
   prefs.xmin   = atof(gtk_entry_get_text(GTK_ENTRY(xmin_en)));
-  prefs.xmax   = MAX(atof(gtk_entry_get_text(GTK_ENTRY(xmax_en))), 
+  prefs.xmax   = MAX(atof(gtk_entry_get_text(GTK_ENTRY(xmax_en))),
 		     prefs.xmin + 10 * prefs.minres);
   prefs.ymin   = atof(gtk_entry_get_text(GTK_ENTRY(ymin_en)));
-  prefs.ymax   = MAX(atof(gtk_entry_get_text(GTK_ENTRY(ymax_en))), 
+  prefs.ymax   = MAX(atof(gtk_entry_get_text(GTK_ENTRY(ymax_en))),
 		     prefs.ymin + 10 * prefs.minres);
   prefs.width  = MAX(atol(gtk_entry_get_text(GTK_ENTRY(width_en))),
 		     10 * prefs.minres);
   prefs.height = MAX(atol(gtk_entry_get_text(GTK_ENTRY(height_en))),
 		     10 * prefs.minres);
-  
+
   if(GTK_TOGGLE_BUTTON(dec_bu)->active)
     prefs.spacing = GEG_RC_DECIMAL;
   else if(GTK_TOGGLE_BUTTON(rad_bu)->active)
@@ -476,31 +476,54 @@ widgets_to_prefs(GtkWidget *widget, gpointer data)
          ValuesKey), 3 * sizeof(gdouble));
   memcpy(&prefs.numb_vals[0], gtk_object_get_data(GTK_OBJECT(numb_pr),
          ValuesKey), 3 * sizeof(gdouble));
-  memcpy(&prefs.axes_vals[0], gtk_object_get_data(GTK_OBJECT(axes_pr), 
+  memcpy(&prefs.axes_vals[0], gtk_object_get_data(GTK_OBJECT(axes_pr),
          ValuesKey), 3 * sizeof(gdouble));
   memcpy(&prefs.sel_vals[0], gtk_object_get_data(GTK_OBJECT(sel_pr),
          ValuesKey), 3 * sizeof(gdouble));
 }
 
-/* atov, this function will cause seg faults if the rc file is not perfect  
+/* atov, this function extracts the color values from the format:
+ *     { %f, %f, %f }
+ * and stores them in vals[]
  */
-static void 
+static void
 atov(gdouble vals[3], char *buf)
 {
+  /* the whole function is essentially the following line */
+  /* sscanf(buf, "{ %f, %f, %f }", &vals[0], &vals[1], &vals[2]); */
+
   while((*buf == ' ') || (*buf == '=') || (*buf == '{'))
-    buf++;
+    buf++;			/* skip to the first number (hopefully) */
 
-  vals[0] = atof(buf);
-  while(*buf != ',')	/* get up to the comma */
-    buf++;
-  while(*++buf == ' '); /* skip the whitespace */
+  if(*buf == '\0')		/* test for string termination */
+    return;
 
-  vals[1] = atof(buf);
-  while(*buf != ',')
+  vals[0] = atof(buf);		/* snag the first value */
+  while(*buf != ',') {		/* get up to the comma */
     buf++;
-  while(*++buf == ' ');
+    if(*buf == '\0')
+      return;
+  }
 
-  vals[2] = atof(buf);
+  while(*++buf == ' ');		/* skip possible whitespace */
+
+  if(*buf == '\0')		/* test for string termination */
+    return;
+
+  vals[1] = atof(buf);		/* snag the second value */
+  while(*buf != ',') {
+    buf++;
+    if(*buf == '\0')
+      return;
+  }
+
+  while(*++buf == ' ');		/* skip possible whitespace */
+
+
+  if(*buf == '\0')		/* test for string termination */
+    return;
+
+  vals[2] = atof(buf);		/* snag the third value */
 }
 
 /* skip_equals, skips to the first non-whitespace character after equals sign
@@ -524,14 +547,15 @@ skip_equals(char **buf)
   return(FALSE);
 }
 
-/* prefs_rc_parse, parses the user's preferences file
- */
 int
 prefs_rc_parse(const gchar *filename)
 {
   FILE *fp;
   char buf[256], *i;
 
+  if(rc_filename)
+    g_free(rc_filename);
+
   /* save the filename for when we write back the preferences */
   rc_filename = g_strdup(filename);
 
@@ -542,9 +566,9 @@ prefs_rc_parse(const gchar *filename)
 
   while(fgets(buf, 256, fp)) {
     i = &buf[0];
-    while(*i == ' ')	/* skip whitespace */
+    while(*i == ' ')
       i++;
-    if((*i == '#') || (*i == '\n'))	/* skip comments and blank lines */
+    if((*i == '#') || (*i == '\n'))
       continue;
 
     /* work out what the setting is */
@@ -560,7 +584,7 @@ prefs_rc_parse(const gchar *filename)
 	  g_warning("error in rcfile %s: %s", filename, buf);
       }
     }
-    else if(!strncasecmp(i, "tooltips", 8)) {  
+    else if(!strncasecmp(i, "tooltips", 8)) {
       if(skip_equals(&i)) {
         if(!strncasecmp(i, "on", 2))
           prefs.tt = GEG_RC_ON;
@@ -595,13 +619,14 @@ prefs_rc_parse(const gchar *filename)
         prefs.height = atol(i);
     }
     else if(!strncasecmp(i, "spacing_type", 12)) {
-      if(skip_equals(&i))
+      if(skip_equals(&i)) {
 	if(!strncasecmp(i, "decimal", 7))
 	  prefs.spacing = GEG_RC_DECIMAL;
 	else if(!strncasecmp(i, "radian", 6))
 	  prefs.spacing = GEG_RC_RADIAN;
 	else
 	  g_warning("error in rcfile %s: %s", filename, buf);
+      }
     }
     else if(!strncasecmp(i, "zoom_factor", 11)) {
       if(skip_equals(&i))
@@ -702,16 +727,16 @@ prefs_rc_write(void)
   fprintf(fp, "ymax = %f\n\n", prefs.ymax);
   fprintf(fp, "graph_width = %d\n", prefs.width);
   fprintf(fp, "graph_height = %d\n", prefs.height);
-  
+
   if(prefs.spacing == GEG_RC_DECIMAL)
     buf = "decimal";
   else if(prefs.spacing == GEG_RC_RADIAN)
     buf = "radian";
   else
     g_assert_not_reached();
-  
+
   fprintf(fp, "spacing_type = %s\n\n", buf);
-  
+
   /* zoom, space, minres, maxres */
   fprintf(fp, "zoom_factor = %f\n", prefs.zoom);
   fprintf(fp, "notch_spacing = %d\n", prefs.space);
